Imports System.Drawing.Design

Public Class LineWidthEditor
    Inherits System.Drawing.Design.UITypeEditor

    ' Indicates that this editor displays a dropdown.
    Public Overloads Overrides Function GetEditStyle(ByVal context As System.ComponentModel.ITypeDescriptorContext) As System.Drawing.Design.UITypeEditorEditStyle
        Return UITypeEditorEditStyle.DropDown
    End Function

    ' Edit a line width.
    Public Overloads Overrides Function EditValue(ByVal context As System.ComponentModel.ITypeDescriptorContext, ByVal provider As System.IServiceProvider, ByVal value As Object) As Object
        ' Get an IWindowsFormsEditorService.
        Dim editor_service As IWindowsFormsEditorService = _
            CType(provider.GetService(GetType(IWindowsFormsEditorService)), _
                IWindowsFormsEditorService)

        ' If we failed to get the editor service, return the value.
        If editor_service Is Nothing Then Return value

        ' Convert the generic value into a line width value.
        Dim line_width As Integer = DirectCast(value, Integer)

        ' Make the editing control.
        Dim editor_control As New LineWidthListBox(line_width, editor_service)

        ' Display the editing control.
        editor_service.DropDownControl(editor_control)

        ' Save the new results.
        Return editor_control.SelectedIndex + 1
    End Function

    ' Indicate that we draw a representation for the Properties window's value.
    Public Overrides Function GetPaintValueSupported(ByVal context As System.ComponentModel.ITypeDescriptorContext) As Boolean
        Return True
    End Function

    ' Draw a representation for the Properties window's value.
    Public Overrides Sub PaintValue(ByVal e As System.Drawing.Design.PaintValueEventArgs)
        e.Graphics.FillRectangle(Brushes.White, e.Bounds)

        Dim line_width As Integer = DirectCast(e.Value, Integer)
        Dim y As Integer = e.Bounds.Y + e.Bounds.Height \ 2
        Using line_pen As New Pen(Color.Black, line_width)
            e.Graphics.DrawLine(line_pen, e.Bounds.Left + 1, y, e.Bounds.Right - 1, y)
        End Using
    End Sub
End Class
